FieldStat<T> class

---------- Aggregated Field Stats ----------

Constructors

FieldStat({required T? consensus, required int consensusCount, required Map<T, int> histogram})

Properties

consensus → T?
final
consensusCount int
final
hashCode int
The hash code for this object.
no setterinherited
histogram Map<T, int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited