ConstData class

Constructors

ConstData({required List<OcrMrzDocumentType> documentType, required List<OcrMrzDocumentDetailType> documentDetailType, required List<OcrMrzDocumentCode> documentCode, required List<DocumentAirport> city, required List<DocumentCountry> country, required List<DocumentAirport> airport})
ConstData.fromJson(Map<String, dynamic> json)
factory
ConstData.offline()
factory

Properties

airport List<DocumentAirport>
final
city List<DocumentAirport>
final
country List<DocumentCountry>
final
documentCode List<OcrMrzDocumentCode>
final
documentDetailType List<OcrMrzDocumentDetailType>
final
documentType List<OcrMrzDocumentType>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<OcrMrzDocumentType>? documentType, List<OcrMrzDocumentDetailType>? documentDetailType, List<OcrMrzDocumentCode>? documentCode, List<DocumentAirport>? city, List<DocumentCountry>? country, List<DocumentAirport>? airport}) ConstData
getLocationWithCode(String code) DocumentCountry?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited