OcrMrzDocumentDetailType class

Constructors

OcrMrzDocumentDetailType({required String type, required String subType, required String country, required String title, required String code, String? note})
OcrMrzDocumentDetailType.fromJson(Map<String, dynamic> json)
factory

Properties

code String
final
country String
final
hashCode int
The hash code for this object.
no setterinherited
note String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subType String
final
title String
final
type String
final

Methods

copyWith({String? type, String? subType, String? country, String? title, String? code, String? note}) OcrMrzDocumentDetailType
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited