OcrMrzDocumentType class

Constructors

OcrMrzDocumentType({required String type, required String color, required String title, required String code})
OcrMrzDocumentType.fromJson(Map<String, dynamic> json)
factory

Properties

code String
final
color String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
type String
final

Methods

copyWith({String? type, String? color, String? title, String? code}) OcrMrzDocumentType
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited