DocumentCodeHelper class

Constructors

DocumentCodeHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

category(String code) String
Returns category (Passport, Visa, etc.)
describe(String code) String
Returns description (if known), or falls back to category
isValid(String code) bool
Returns true if code is a valid doc code prefix