OcrMrzDocumentDetail class

Constructors

OcrMrzDocumentDetail({String? documentNumber, String? shortType, List<String> suggestionCodes = const [], String? fullName, String? firstName, String? lastName, String? middleName, OcrMrzDocumentCode? documentCode, DateTime? documentExpiryDate, DateTime? birthDate, DocumentCountry? documentIssueCountry, DateTime? documentIssueDate, DocumentCountry? nationality, DateTime? applicationDate, String? mrz, String? ocrText, String? docCode, String? sex, bool verifiedDocNum = false, bool verifiedDocCode = false})
const
OcrMrzDocumentDetail.fromJson(Map<String, dynamic> json)
factory
OcrMrzDocumentDetail.fromMrzResult(OcrMrzResult res)
factory
OcrMrzDocumentDetail.passport()
factory
OcrMrzDocumentDetail.resident()
factory
OcrMrzDocumentDetail.visa()
factory

Properties

applicationDate DateTime?
final
birthDate DateTime?
final
birthDayIndex int
no setter
birthdayLabel String
no setter
docCode String?
final
documentCode OcrMrzDocumentCode?
final
documentExpiryDate DateTime?
final
documentIssueCountry DocumentCountry?
final
documentIssueDate DateTime?
final
documentNumber String?
final
expiryRemain int?
no setter
firstName String?
final
fullName String?
final
gender Gender?
no setter
getMrzWidget Widget
no setter
hashCode int
The hash code for this object.
no setterinherited
isBirthday bool
no setter
isEmpty bool
no setter
isExpired bool
no setter
isExpiring bool
no setter
isExpiryFake bool
no setter
isPassport bool
no setter
isScanned bool
no setter
isVisa bool
no setter
lastName String?
final
middleName String?
final
mrz String?
final
nationality DocumentCountry?
final
ocrText String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sex String?
final
shortType String?
final
suggestionCodes List<String>
final
verifiedDocCode bool
final
verifiedDocNum bool
final

Methods

copyWith({Object? documentNumber = _unset, Object? fullName = _unset, Object? firstName = _unset, Object? lastName = _unset, Object? documentCode = _unset, Object? documentExpiryDate = _unset, Object? birthDate = _unset, Object? documentIssueCountry = _unset, Object? documentIssueDate = _unset, Object? nationality = _unset, Object? documentMRZType = _unset, Object? documentSeries = _unset, Object? documentFeature = _unset, Object? applicationDate = _unset, Object? mrz = _unset, Object? ocrText = _unset, Object? shortType = _unset, Object? docCode = _unset, Object? sex = _unset, Object? verifiedDocNum = _unset, Object? verifiedDocCode = _unset, Object? suggestionCodes = _unset}) OcrMrzDocumentDetail
getMatch([ConstData? data]) OcrMrzDocumentType?
getTypeDetailsMatch([ConstData? data]) OcrMrzDocumentDetailType?
isSameAs(OcrMrzResult res, {List<String?> notThis = const []}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited