Gender enum
- Inheritance
- Available extensions
Values
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Available on Gender, provided by the GenderDetails extension
no setter - value → String
-
Available on Gender, provided by the GenderDetails extension
no setter
Methods
-
genderFromJson(
String? v) → Gender? -
Available on Gender, provided by the GenderDetails extension
-
genderToJson(
Gender? t) → String? -
Available on Gender, provided by the GenderDetails extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited