IssueDateGuess class

Constructors

IssueDateGuess(String yymmdd, DateTime fullDate, String source, double confidence)

Properties

confidence double
final
fullDate DateTime
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
yymmdd String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited