MrzParser class

Constructors

MrzParser({int confidence = 1})

Properties

confidence int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getProgress(OcrData ocrData) Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(OcrData ocrData, {MrzValidationSettings settings = const MrzValidationSettings()}) MrzResult?
reset() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited