MrzCheckDigitResult class
A container for the validation status of each check digit.
Constructors
Properties
- birthDate → bool
-
final
- documentNumber → bool
-
final
- expiryDate → bool
-
final
- finalComposite → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- optionalData → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited