CheckDigits class

Constructors

CheckDigits({required bool document, required bool birth, required bool expiry, required bool optional, bool? finalComposite})
CheckDigits.fromJson(Map<String, dynamic> json)
factory

Properties

birth bool
getter/setter pair
document bool
Unified doc number check (passport/visa).
getter/setter pair
expiry bool
getter/setter pair
finalComposite bool?
Passports have a composite final check; visas do NOT. If null => not applicable.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
optional bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited