MrzName class

Constructors

MrzName({required String rawSurname, required List<String> rawGivenNames, required String surname, required List<String> givenNames, required String full})

Properties

firstName String
no setter
full String
final
givenNames List<String>
final
hashCode int
The hash code for this object.
no setterinherited
lastName String
no setter
rawGivenNames List<String>
final
rawSurname String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surname String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateNames(Iterable<String> lines, OcrMrzSetting setting, List<NameValidationData> names) → (bool, String, MrzName)

Operators

operator ==(Object other) bool
The equality operator.
inherited