OcrBodyBuilder typedef
A typedef for a function that builds the body of an API request
from a list of OcrData objects captured during the interval.
Implementation
typedef OcrBodyBuilder = Map<String, dynamic> Function(List<OcrData> ocrDataList);
A typedef for a function that builds the body of an API request
from a list of OcrData objects captured during the interval.
typedef OcrBodyBuilder = Map<String, dynamic> Function(List<OcrData> ocrDataList);