OcrMrzApiConfig class

Configuration for making periodic API calls to an external service for MRZ recognition.

Constructors

OcrMrzApiConfig({required String url, required Map<String, String> headers, required OcrBodyBuilder bodyBuilder, required Duration interval, bool attachPhoto = false, int photoQuality = 85, int? photoMaxWidth})

Properties

attachPhoto bool
Whether to capture and attach a photo to the API request. If true, the request will be sent as multipart/form-data.
final
bodyBuilder OcrBodyBuilder
A function that takes a list of OcrData and returns a Map to be used as the JSON body of the request.
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
The headers to include in the HTTP request.
final
interval Duration
The interval at which to make the API calls.
final
photoMaxWidth int?
The maximum width of the photo in pixels. The image will be resized proportionally if it's wider than this value. If null, the original width is used. Only used if attachPhoto is true.
final
photoQuality int
The quality of the attached JPEG photo (0-100). Defaults to 85. Only used if attachPhoto is true.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
The URL of the API endpoint to call.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited