OcrMrzControllerNew class

A dedicated controller for the new OcrMrzReaderNew widget.

Inheritance
  • Object
  • CameraKitPlus
  • CameraKitPlusController
  • OcrMrzControllerNew

Constructors

OcrMrzControllerNew({OcrMrzApiConfig? apiConfig, int confidence = 3})

Properties

apiConfig OcrMrzApiConfig?
getter/setter pair
apiConfigNotifier ValueNotifier<OcrMrzApiConfig?>
no setter
hashCode int
The hash code for this object.
no setterinherited
mrzParser MrzParser
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

changeApiConfig(OcrMrzApiConfig? newConfig) → void
changeFlashMode(CameraKitPlusFlashMode mode) Future<bool>
inherited
clearOcrRotation() Future<bool?>
inherited
dispose() → void
getCameraPermission() Future<bool>
inherited
getPlatformVersion() Future<String?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseCamera() Future<bool>
inherited
resetSession() → void
Resets the entire scanning session, including the parser's internal state.
resumeCamera() Future<bool>
inherited
setMacro(bool macro) Future<bool?>
inherited
setOcrRotation(int degree) Future<bool?>
inherited
setShowTextRectangles(bool show) Future<bool?>
inherited
setZoom(double zoom) Future<bool?>
inherited
switchCamera(CameraKitPlusCameraMode mode) Future<bool>
inherited
takePicture() Future<String?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited