OcrMrzReader class

Inheritance

Constructors

OcrMrzReader({Key? key, required void onFoundMrz(OcrMrzResult res), OcrMrzSetting? setting, List<NameValidationData>? nameValidations, void mrzLogger(OcrMrzLog log)?, List<DocumentType> filterTypes = const [], required OcrMrzController controller, bool showFrame = true, bool showZoom = true, void onSessionChange(List<SessionStatus> sessionList)?, OcrMrzCountValidation? countValidation, void onConsensusChanged(OcrMrzConsensus sessionList)?, bool isActive = true})

Properties

controller OcrMrzController
final
countValidation OcrMrzCountValidation?
final
filterTypes List<DocumentType>
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mrzLogger → void Function(OcrMrzLog log)?
final
nameValidations List<NameValidationData>?
final
onConsensusChanged → void Function(OcrMrzConsensus sessionList)?
final
onFoundMrz → void Function(OcrMrzResult res)
final
onSessionChange → void Function(List<SessionStatus> sessionList)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setting OcrMrzSetting?
final
showFrame bool
final
showZoom bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<OcrMrzReader>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited