ApiResponse class

Constructors

ApiResponse({required bool success, required int errorCode, required String message, DocumentScanResponse? response})
const
ApiResponse.fromJson(Map<String, dynamic> json)
factory

Properties

errorCode int
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
response DocumentScanResponse?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toOcrMrzResult() OcrMrzResult
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited