ConfidenceField class

Constructors

ConfidenceField({String? value, required int percent, String? checkDigit})
const
ConfidenceField.fromJson(Map<String, dynamic> json)
factory

Properties

checkDigit String?
final
hashCode int
The hash code for this object.
no setterinherited
percent int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited