SessionOcrHandlerConsensus class

Constructors

SessionOcrHandlerConsensus({required SessionLogger logger})

Properties

hashCode int
The hash code for this object.
no setterinherited
logger SessionLogger
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleSession(OcrMrzAggregator aggregator, OcrData ocr, OcrMrzSetting setting, List<NameValidationData> names) OcrMrzConsensus
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

normalize(String line) String
normalizeWithLength(String line, {int len = 44}) String