OcrMrzDocumentDetailType class
Constructors
- OcrMrzDocumentDetailType({required String type, required String subType, required String country, required String title, required String code, String? note})
-
OcrMrzDocumentDetailType.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
copyWith(
{String? type, String? subType, String? country, String? title, String? code, String? note}) → OcrMrzDocumentDetailType -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited