MrzValidationSettings class
Defines which fields must be successfully parsed to consider an MRZ valid.
Constructors
- MrzValidationSettings({bool validateDocumentNumber = true, bool validateBirthDate = true, bool validateExpiryDate = true, bool validateNames = true, bool validateNationality = true, bool validateCountryCode = true, bool validateFinalCheckDigit = false})
-
By default, all core fields are required, but the final composite check digit is optional.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validateBirthDate → bool
-
final
- validateCountryCode → bool
-
final
- validateDocumentNumber → bool
-
final
- validateExpiryDate → bool
-
final
- validateFinalCheckDigit → bool
-
final
- validateNames → bool
-
final
- validateNationality → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited