attachPhoto property
Whether to capture and attach a photo to the API request.
If true, the request will be sent as multipart/form-data.
Implementation
final bool attachPhoto;
Whether to capture and attach a photo to the API request.
If true, the request will be sent as multipart/form-data.
final bool attachPhoto;