OcrMrzController class
- Inheritance
-
- Object
- CameraKitPlus
- CameraKitPlusController
- OcrMrzController
Constructors
- OcrMrzController({SessionLogger? sessionLogger, OcrMrzApiConfig? apiConfig})
Properties
- aggregator → OcrMrzAggregator
-
final
- apiConfig ↔ OcrMrzApiConfig?
-
getter/setter pair
-
apiConfigNotifier
→ ValueNotifier<
OcrMrzApiConfig?> -
no setter
-
getSessionHistory
→ ValueNotifier<
List< SessionStatus> > -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger ↔ SessionLogger
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addSessionHistory(
SessionStatus s) → void -
changeApiConfig(
OcrMrzApiConfig? newConfig) → void -
changeFlashMode(
CameraKitPlusFlashMode mode) → Future< bool> -
inherited
-
clearOcrRotation(
) → Future< bool?> -
inherited
-
debug(
String s, ParseAlgorithm alg, void onFoundMrz(OcrMrzResult res)) → dynamic -
dispose(
) → void -
flashOn(
) → dynamic -
getCameraPermission(
) → Future< bool> -
inherited
-
getPlatformVersion(
) → Future< String?> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pauseCamera(
) → Future< bool> -
inherited
-
resetSession(
) → dynamic -
resumeCamera(
) → Future< bool> -
inherited
-
setMacro(
bool macro) → Future< bool?> -
inherited
-
setOcrRotation(
int degree) → Future< bool?> -
inherited
-
setSessionHistory(
List< SessionStatus> sh) → void -
setShowTextRectangles(
bool show) → Future< bool?> -
inherited
-
setZoom(
double zoom) → Future< bool?> -
inherited
-
switchCamera(
CameraKitPlusCameraMode mode) → Future< bool> -
inherited
-
takePicture(
) → Future< String?> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited