SessionLogger class
Constructors
-
SessionLogger({int maxLogSize = 500, void onLog(SessionLogEntry entry)?, void onLogBatch(List<
SessionLogEntry> entries, LogFlushReason reason)?, Duration? logInterval})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logInterval → Duration?
-
final
- maxLogSize → int
-
final
- onLog → void Function(SessionLogEntry entry)?
-
final
-
onLogBatch
→ void Function(List<
SessionLogEntry> entries, LogFlushReason reason)? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void -
dispose(
) → void -
flush(
{LogFlushReason reason = LogFlushReason.success}) → void - Manually flushes the log buffer, calling onLogBatch if it's configured.
-
getFormattedLogs(
) → String -
log(
{required String message, int? step, Map< String, dynamic> details = const {}}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited